==> GitPython-2.0.9.dev0-py2.py3-none-any.whl: git/__init__.py <==
# __init__.py
# Copyright (C) 2008, 2009 Michael Trier (mtrier@gmail.com) and contributors
#
# This module is part of GitPython and is released under
# the BSD License: http://www.opensource.org/licenses/bsd-license.php
# flake8: noqa
#@PydevCodeAnalysisIgnore
import os
import sys
import inspect

__version__ = '2.0.9dev0'


#{ Initialization
def _init_externals():
    """Initialize external projects by putting them into the path"""
    if __version__ == '2.0.9dev0':
        sys.path.insert(0, os.path.join(os.path.dirname(__file__), 'ext', 'gitdb'))

    try:
        import gitdb
    except ImportError:
        raise ImportError("'gitdb' could not be found in your PYTHONPATH")
    # END verify import

#} END initialization

#################
_init_externals()
#################

#{ Imports

from git.config import GitConfigParser  # @NoMove @IgnorePep8
from git.objects import *               # @NoMove @IgnorePep8
from git.refs import *                  # @NoMove @IgnorePep8
from git.diff import *                  # @NoMove @IgnorePep8
from git.exc import *                   # @NoMove @IgnorePep8
from git.db import *                    # @NoMove @IgnorePep8
from git.cmd import Git                 # @NoMove @IgnorePep8
from git.repo import Repo               # @NoMove @IgnorePep8
from git.remote import *                # @NoMove @IgnorePep8
from git.index import *                 # @NoMove @IgnorePep8
from git.util import (                  # @NoMove @IgnorePep8
    LockFile,
    BlockingLockFile,
    Stats,
    Actor
)

#} END imports

__all__ = [name for name, obj in locals().items()
           if not (name.startswith('_') or inspect.ismodule(obj))]

==> GitPython-2.1.0-py2.py3-none-any.whl: git/__init__.py <==
# __init__.py
# Copyright (C) 2008, 2009 Michael Trier (mtrier@gmail.com) and contributors
#
# This module is part of GitPython and is released under
# the BSD License: http://www.opensource.org/licenses/bsd-license.php
# flake8: noqa
#@PydevCodeAnalysisIgnore
import inspect
import os
import sys

import os.path as osp


__version__ = '2.1.0'


#{ Initialization
def _init_externals():
    """Initialize external projects by putting them into the path"""
    if __version__ == '2.1.0':
        sys.path.insert(0, osp.join(osp.dirname(__file__), 'ext', 'gitdb'))

    try:
        import gitdb
    except ImportError:
        raise ImportError("'gitdb' could not be found in your PYTHONPATH")
    # END verify import

#} END initialization

#################
_init_externals()
#################

#{ Imports

from git.config import GitConfigParser  # @NoMove @IgnorePep8
from git.objects import *               # @NoMove @IgnorePep8
from git.refs import *                  # @NoMove @IgnorePep8
from git.diff import *                  # @NoMove @IgnorePep8
from git.exc import *                   # @NoMove @IgnorePep8
from git.db import *                    # @NoMove @IgnorePep8
from git.cmd import Git                 # @NoMove @IgnorePep8
from git.repo import Repo               # @NoMove @IgnorePep8
from git.remote import *                # @NoMove @IgnorePep8
from git.index import *                 # @NoMove @IgnorePep8
from git.util import (                  # @NoMove @IgnorePep8
    LockFile,
    BlockingLockFile,
    Stats,
    Actor
)

#} END imports

__all__ = [name for name, obj in locals().items()
           if not (name.startswith('_') or inspect.ismodule(obj))]
